aiosql.adapters package
=======================

Submodules
----------

aiosql.adapters.aiosqlite module
--------------------------------

.. automodule:: aiosql.adapters.aiosqlite
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.asyncpg module
------------------------------

.. automodule:: aiosql.adapters.asyncpg
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.duckdb module
-----------------------------

.. automodule:: aiosql.adapters.duckdb
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.generic module
------------------------------

.. automodule:: aiosql.adapters.generic
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.mysql module
----------------------------

.. automodule:: aiosql.adapters.mysql
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.pg8000 module
-----------------------------

.. automodule:: aiosql.adapters.pg8000
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.pyformat module
-------------------------------

.. automodule:: aiosql.adapters.pyformat
   :members:
   :undoc-members:
   :show-inheritance:

aiosql.adapters.sqlite3 module
------------------------------

.. automodule:: aiosql.adapters.sqlite3
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aiosql.adapters
   :members:
   :undoc-members:
   :show-inheritance:
